import { defineConfig } from 'astro/config';
import starlight from "@astrojs/starlight";

import { navigation } from "./src/components/navigation.ts";

export default defineConfig({
  integrations: [starlight({
    title: "Naomi's Documentation",
    sidebar: navigation,
    tableOfContents: { minHeadingLevel: 2, maxHeadingLevel: 4},
    description: "Helpful documentation we want to share with everyone.",
    editLink: {
      baseUrl: "https://codeberg.org/nhcarrigan/docs/_edit/main/",
      label: "Edit this page on Codeberg"
    },
    lastUpdated: true,
    social: {
      codeberg: "https://codeberg.org/nhcarrigan",
      github: "https://github.com/nhcarrigan",
      discord: "https://chat.nhcarrigan.com"
    },
    head: [
      {
        tag: "script",
        attrs: {
          type: "text/javascript",
          id: "hs-script-loader",
          async: true,
          defer: true,
          src: "//js.hs-scripts.com/47086586.js"
        }
      },
      {
        tag: "script",
        attrs: {
          type: "text/javascript",
          id: "analytics",
          src: "https://analytics.nhcarrigan.com/js/script.file-downloads.outbound-links.js",
          defer: true,
          "data-domain": "docs.nhcarrigan.com"
        }
      },
      {
        tag: "script",
        content: "window.plausible = window.plausible || function() { (window.plausible.q = window.plausible.q || []).push(arguments) }"
      }
    ],
    customCss: [
      "./src/styles/style.css"
    ]
  })]
});
